# checkjpy2hkd
Check the latest JPY to HKD exchange rates

## Installation
You can install the JPY to HKD Exchange Rate Checker from [PyPI](https://pypi.org/project/checkjpy2hkd/):

    python -m pip install checkjpy2hkd

## How to use
The JPY to HKD Exchange Rate Checker is a command line application, named `checkjpy2hkd`.

You can also call the JPY to HKD Exchange Rate Checker in your own Python code, by importing from the `reader` package:

    >>> from checkjpy2hkd import xxx
    >>> xxx()